@@ -9,5 +9,7 @@ int chrpath(const char *filename, const char *newpath, int convert);
 int elf_open(const char *filename, int flags, Elf32_Ehdr *ehdr);
 void elf_close(int fd);
 int elf_find_dynamic_section(int fd, Elf32_Ehdr *ehdr, Elf32_Phdr *phdr);
+const char *elf_tagname(int tag);
+int elf_dynpath_tag(int tag);
 
 #endif /* PROTOS_H */
